==> zrythm-0.8.200.tar.xz: zrythm-0.8.200/inc/gui/widgets/modulator.h <==
/*
 * Copyright (C) 2019 Alexandros Theodotou <alex at zrythm dot org>
 *
 * This file is part of Zrythm
 *
 * Zrythm is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Zrythm is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Zrythm.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __GUI_WIDGETS_MODULATOR_H__
#define __GUI_WIDGETS_MODULATOR_H__

#include "audio/track.h"
#include "gui/widgets/two_col_expander_box.h"

#include <gtk/gtk.h>

#define MODULATOR_WIDGET_TYPE \
  (modulator_widget_get_type ())
G_DECLARE_FINAL_TYPE (
  ModulatorWidget,
  modulator_widget,
  Z, MODULATOR_WIDGET,
  TwoColExpanderBoxWidget)

typedef struct _KnobWithNameWidget KnobWithNameWidget;
typedef struct Modulator Modulator;

typedef struct _ModulatorWidget
{
  TwoColExpanderBoxWidget  parent_instance;

  /** The controls box on the left. */
  GtkBox *                 controls_box;

  KnobWithNameWidget *     knobs[MAX_MODULATORS];
  int                      num_knobs;

  /** The graph on the right. */
  GtkDrawingArea *         graph;

  /** Width is 60 so 59 previous points per
   * CV out (max 6). */
  double                   prev_points[6][60];

  /** Pointer back to the Modulator. */
  Modulator *              modulator;
} ModulatorWidget;

ModulatorWidget *
modulator_widget_new (
  Modulator * modulator);

#endif

==> zrythm-0.8.911.tar.xz: zrythm-0.8.911/inc/gui/widgets/modulator.h <==
/*
 * Copyright (C) 2019 Alexandros Theodotou <alex at zrythm dot org>
 *
 * This file is part of Zrythm
 *
 * Zrythm is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Zrythm is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Zrythm.  If not, see <https://www.gnu.org/licenses/>.
 */

/**
 * @file
 *
 * Modulator.
 */

#ifndef __GUI_WIDGETS_MODULATOR_H__
#define __GUI_WIDGETS_MODULATOR_H__

#include "audio/track.h"
#include "gui/widgets/two_col_expander_box.h"

#include <gtk/gtk.h>

typedef struct _KnobWithNameWidget
  KnobWithNameWidget;
typedef struct _LiveWaveformWidget
  LiveWaveformWidget;
typedef struct _PortConnectionsPopoverWidget
  PortConnectionsPopoverWidget;
typedef struct Modulator Modulator;

/**
 * @addtogroup widgets
 *
 * @{
 */

#define MODULATOR_WIDGET_TYPE \
  (modulator_widget_get_type ())
G_DECLARE_FINAL_TYPE (
  ModulatorWidget,
  modulator_widget,
  Z, MODULATOR_WIDGET,
  TwoColExpanderBoxWidget)

/**
 * Modulator.
 */
typedef struct _ModulatorWidget
{
  TwoColExpanderBoxWidget  parent_instance;

  /** The controls box on the left. */
  GtkBox *          controls_box;

  KnobWithNameWidget ** knobs;
  int               num_knobs;
  int               knobs_size;

  /** The graphs on the right. */
  GtkBox *          waveforms_box;
  GtkOverlay *      waveform_overlays[16];
  GtkButton *       waveform_automate_buttons[16];
  //PortConnectionsPopoverWidget *
    //waveform_popovers[16];
  LiveWaveformWidget * waveforms[16];
  int               num_waveforms;

  Port *            ports[16];

  //GtkDrawingArea *  graph;

  /** Width is 60 so 59 previous points per
   * CV out (max 16). */
  //double            prev_points[16][60];

  /** Pointer back to the Modulator. */
  Plugin *          modulator;
} ModulatorWidget;

ModulatorWidget *
modulator_widget_new (
  Plugin * modulator);

/**
 * @}
 */

#endif
